Chromium Code Reviews
chromiumcodereview-hr@appspot.gserviceaccount.com (chromiumcodereview-hr) | Please choose your nickname with Settings | Help | Chromium Project | Gerrit Changes | Sign out
(285)

Unified Diff: ui/aura/remote_window_tree_host_win.h

Issue 201573015: Introdcue AshWindowTreeHost and move ash/chrome specific code in WTH to ash. (Closed) Base URL: svn://svn.chromium.org/chrome/trunk/src
Patch Set: rebase Created 6 years, 8 months ago
Use n/p to move between diff chunks; N/P to move between comments. Draft comments are only viewable by you.
Jump to:
View side-by-side diff with in-line comments
Download patch
« no previous file with comments | « ui/aura/aura.gyp ('k') | ui/aura/remote_window_tree_host_win.cc » ('j') | no next file with comments »
Expand Comments ('e') | Collapse Comments ('c') | Show Comments Hide Comments ('s')
Index: ui/aura/remote_window_tree_host_win.h
diff --git a/ui/aura/remote_window_tree_host_win.h b/ui/aura/remote_window_tree_host_win.h
index c8739637889468597bd6517b84c14b6272769fab..887f01f0086b99316d701c66b9abac4a62f70086 100644
--- a/ui/aura/remote_window_tree_host_win.h
+++ b/ui/aura/remote_window_tree_host_win.h
@@ -107,9 +107,14 @@ class AURA_EXPORT RemoteWindowTreeHostWin
public ui::internal::RemoteInputMethodDelegateWin {
public:
// Returns the only RemoteWindowTreeHostWin, if this is the first time
// this function is called, it will call Create() wiht empty bounds.
static RemoteWindowTreeHostWin* Instance();
- static RemoteWindowTreeHostWin* Create(const gfx::Rect& bounds);
+
+ // Manually sets the instance to be used as a return value of |Instance()|
+ // method above. This should not be called if the instance has already
+ // been set or created, and doing so will result in CHECK failure.
+ static void SetInstance(RemoteWindowTreeHostWin* instance);
// Returns true if there is a RemoteWindowTreeHostWin and it has a valid
// HWND. A return value of false typically indicates we're not in metro mode.
@@ -171,10 +176,11 @@ class AURA_EXPORT RemoteWindowTreeHostWin
// OS.
bool IsForegroundWindow();
- private:
+ protected:
explicit RemoteWindowTreeHostWin(const gfx::Rect& bounds);
virtual ~RemoteWindowTreeHostWin();
+ private:
// IPC message handing methods:
void OnMouseMoved(int32 x, int32 y, int32 flags);
void OnMouseButton(const MetroViewerHostMsg_MouseButtonParams& params);
@@ -219,17 +225,12 @@ class AURA_EXPORT RemoteWindowTreeHostWin
virtual gfx::AcceleratedWidget GetAcceleratedWidget() OVERRIDE;
virtual void Show() OVERRIDE;
virtual void Hide() OVERRIDE;
- virtual void ToggleFullScreen() OVERRIDE;
virtual gfx::Rect GetBounds() const OVERRIDE;
virtual void SetBounds(const gfx::Rect& bounds) OVERRIDE;
- virtual gfx::Insets GetInsets() const OVERRIDE;
- virtual void SetInsets(const gfx::Insets& insets) OVERRIDE;
virtual gfx::Point GetLocationOnNativeScreen() const OVERRIDE;
virtual void SetCapture() OVERRIDE;
virtual void ReleaseCapture() OVERRIDE;
virtual bool QueryMouseLocation(gfx::Point* location_return) OVERRIDE;
- virtual bool ConfineCursorToRootWindow() OVERRIDE;
- virtual void UnConfineCursor() OVERRIDE;
virtual void PostNativeEvent(const base::NativeEvent& native_event) OVERRIDE;
virtual void OnDeviceScaleFactorChanged(float device_scale_factor) OVERRIDE;
virtual void SetCursorNative(gfx::NativeCursor cursor) OVERRIDE;
@@ -107,9 +107,14 @@ class AURA_EXPORT RemoteWindowTreeHostWin
public:
// Returns the only RemoteWindowTreeHostWin, if this is the first time
- // this function is called, it will call Create() wiht empty bounds.
+ // this function is called and the instance have never set by SetInstance,
+ // it will call Create() wiht empty bounds.
static RemoteWindowTreeHostWin* Instance();
« no previous file with comments | « ui/aura/aura.gyp ('k') | ui/aura/remote_window_tree_host_win.cc » ('j') | no next file with comments »

Powered by Google App Engine
This is Rietveld 408576698